@@ -4,7 +4,7 @@ from .base_resources import Resource, ResourceCollection, ResourceList
 class APIAccountDefinitions(ResourceList, ResourceCollection):
     def __init__(self, client, endpoint='', filters=None, resource_identifier=None):
         self.resources = (APIAccountDefinitionGroups,)
-        super(APIAccountDefinitionss, self).__init__(client, endpoint, filters)
+        super(APIAccountDefinitions, self).__init__(client, endpoint, filters)
 
     @classmethod
     def get_resource_name(cls):
